<?php
/* Author: Claudio Ferreira Filho */

$labels = array();
$labels['collapseall'] = 'Recolher todas as pastas';
$labels['expandall'] = 'Expandir todas as pastas';
$labels['assigngroup'] = 'Atribuir contatos selecionados ao grupo...';

$messages = array();
