<?php
/* Author: Wouter Kevenaar */

$labels = array();
$labels['collapseall'] = 'Alle mappen inklappen';
$labels['expandall'] = 'Alle mappen uitklappen';
$labels['assigngroup'] = 'Geselecteerde contacten toewijzen aan groep...';

$messages = array();
