<?php
/* Author: Sergio Loyola */

$labels = array();
$labels['markreadfolder'] = 'Marcar todo como leído';
$labels['collapseall'] = 'Compactar todas las carpetas';
$labels['expandall'] = 'Expandir todas las carpetas';
$labels['assigngroup'] = 'Asignar contactos seleccionados al grupo ...';

$messages = array();

?>
