/**
 * ContextMenu plugin styles
 */

.contextRow td,
#mailboxlist li.contextRow,
#directorylistbox li.contextRow
{
  background-color: #EEEEEE;
}

#mailboxlist li.selected,
#directorylistbox li.selected
{
  background-color: #929292;
}

div.contextmenu li a.active:hover
{
  color: #fff;
}

div.contextmenu a
{
  position: relative;
  outline: 0;
  padding: 0 !important;
}

div.contextmenu ul.iconized li a span
{
  display: block;
  padding: 1px 12px 3px 28px;
}

div.contextmenu ul.iconized li a span.icon
{
  background: url(images/contexticons.png) no-repeat 0 20px;
}

div.contextmenu ul.iconized li.submenu a span.icon
{
  padding-right: 15px;
}

div.contextmenu ul.iconized li.submenu a span.right-arrow
{
  position: absolute;
  top: 0;
  right: 0;
  height: 15px;
  width: 15px;
  background: url(images/contexticons.png) no-repeat right 1px;
}

div.contextmenu ul.iconized li a.reply span.icon
{
  background-position: 7px -119px;
}

div.contextmenu ul.iconized li a.replyAll span.icon
{
  background-position: 7px -392px;
}

div.contextmenu ul.iconized li a.replyalllink span.icon
{
  background-position: 7px -392px;
}

div.contextmenu ul.iconized li a.replylistlink span.icon
{
  background-position: 7px -377px;
}

div.contextmenu ul.iconized li a.forward span.icon
{
  background-position: 7px -102px;
}

div.contextmenu ul.iconized li a.forwardlink span.icon
{
  background-position: 7px -102px;
}

div.contextmenu ul.iconized li a.forwardattachmentlink span.icon
{
  background-position: 7px -361px;
}

div.contextmenu ul.iconized li a.delete span.icon
{
  background-position: 7px -187px;
}

div.contextmenu ul.iconized li a.markmessage span.icon
{
  background-position: 7px -457px;
}

div.contextmenu ul.iconized li a.readlink span.icon
{
  background-position: 7px -85px;
}

div.contextmenu ul.iconized li a.unreadlink span.icon
{
  background-position: 7px -136px;
}
div.contextmenu ul.iconized li a.flaggedlink span.icon
{
  background-position: 7px -170px;
}

div.contextmenu ul.iconized li a.unflaggedlink span.icon
{
  background-position: 7px -153px;
}

div.contextmenu ul.iconized li a.messagemenu span.icon
{
  background-position: 7px -475px;
}

div.contextmenu ul.iconized li a.compose span.icon
{
  background-position: 8px -237px;
}

div.contextmenu ul.iconized li a.print span.icon
{
  background: url(images/messageactions.png) no-repeat 5px 1px;
}

div.contextmenu ul.iconized li a.cmd_mark-all-read span.icon
{
  background-position: 7px -85px;
}

div.contextmenu ul.iconized li a.collapseall span.icon
{
  background-position: 7px -203px;
}
div.contextmenu ul.iconized li a.expandall span.icon
{
  background-position: 7px -219px;
}

div.contextmenu ul.iconized li a.cmd_expunge span.icon
{
  background-position: 7px -254px;
}

div.contextmenu ul.iconized li a.cmd_purge span.icon
{
  background-position: 7px -271px;
}

div.contextmenu ul.iconized li a.openfolder span.icon
{
  background: url(images/messageactions.png) no-repeat 6px -52px;
}

div.contextmenu ul.iconized li a.movecontact span.icon
{
  background: url(images/messageactions.png) no-repeat 5px -161px;
}

div.contextmenu ul.iconized li a.copycontact span.icon
{
  background: url(images/messageactions.png) no-repeat 5px -143px;
}

div.contextmenu ul.iconized li a.export span.icon
{
  background-position: 7px -510px;
}

div.contextmenu ul.iconized li a.exportalllink span.icon
{
  background-position: 7px -527px;
}

div.contextmenu ul.iconized li a.exportsellink span.icon
{
  background-position: 7px -510px;
}

div.contextmenu ul.iconized li a.cmd_add-recipient span.icon
{
  background-position: 8px -236px;
}

div.contextmenu ul.iconized li a.vcard span.icon
{
  background-position: 7px -546px;
}

div.contextmenu ul.iconized li a.cmd_group-create span.icon,
div.contextmenu ul.iconized li a.assigngroup span.icon
{
  background-position: 7px -441px;
}

div.contextmenu ul.iconized li a.cmd_group-remove-selected span.icon
{
  background-position: 7px -492px;
}

div.contextmenu ul.iconized li a.cmd_group-rename span.icon
{
  background-position: 7px -426px;
}

div.contextmenu ul.iconized li a.cmd_group-delete span.icon
{
  background-position: 7px -186px;
}

div.contextmenu ul.iconized li a.cmd_search-delete span.icon
{
  background-position: 7px -186px;
}

#rcm_messagemenumenu ul.iconized li a span.icon
{
  background: url(images/messageactions.png) no-repeat 5px 20px;
}

#rcm_messagemenumenu ul.iconized li a.printlink span.icon
{
  background-position: 5px 1px;
}

#rcm_messagemenumenu ul.iconized li a.downloadlink span.icon
{
  background-position: 5px -17px;
}

#rcm_messagemenumenu ul.iconized li a.editlink span.icon
{
  background-position: 5px -70px;
}

#rcm_messagemenumenu ul.iconized li a.movelink span.icon
{
  background-position: 5px -161px;
}

#rcm_messagemenumenu ul.iconized li a.copylink span.icon
{
  background-position: 5px -143px;
}

#rcm_messagemenumenu ul.iconized li a.sourcelink span.icon
{
  background-position: 5px -35px;
}

#rcm_messagemenumenu ul.iconized li a.openlink span.icon
{
  background-position: 5px -52px;
}

/*** address book selector ***/

#addressbook-selector li a,
#addressgroup-selector li a
{
  padding: 0;
}

#addressbook-selector li a span,
#addressgroup-selector li a span
{
  background: url(images/contexticons.png) no-repeat 0 20px;
  display: block;
  height: 15px;
  min-height: 14px;
  padding: 2px 4px 2px 28px;
  overflow: hidden;
  max-width: 120px;
  text-overflow: ellipsis;
}

#addressbook-selector li a.active:hover span,
#addressgroup-selector li a.active:hover span
{
  color: white;
}

#addressbook-selector li a.addressbook span
{
  background-position: 5px -306px;
}

#addressbook-selector li a.contactgroup span,
#addressgroup-selector li a.contactgroup span
{
  background-position: 5px -343px;
}