<?php
/* Author: Mike Constabel */

$labels = array();
$labels['collapseall'] = 'Alle Unterordner einklappen';
$labels['expandall'] = 'Alle Unterordner ausklappen';
$labels['assigngroup'] = 'Gewählte Kontakte einer Gruppe zuordnen';

$messages = array();
